RpcSubscriptionsConfig class

Configuration for creating an RpcSubscriptions instance.

Constructors

RpcSubscriptionsConfig({required RpcSubscriptionsApi api, required RpcSubscriptionsTransport transport})
Creates a new RpcSubscriptionsConfig.
const

Properties

api RpcSubscriptionsApi
The subscriptions API.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport RpcSubscriptionsTransport
The subscriptions transport.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited