RpcSubscriptionsTransportExecuteConfig class

Configuration for executing a subscription on a channel.

Constructors

RpcSubscriptionsTransportExecuteConfig({required RpcSubscriptionsChannel channel, required CancellationToken signal})
Creates a new RpcSubscriptionsTransportExecuteConfig.
const

Properties

channel → RpcSubscriptionsChannel
The channel to execute the subscription on.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signal CancellationToken
Cancellation token for aborting the subscription.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited