ChannelPoolEntry class
An entry in the channel pool.
Constructors
-
ChannelPoolEntry({required Future<
RpcSubscriptionsChannel> channel, required void dispose(), int subscriptionCount = 0}) - Creates a new ChannelPoolEntry.
Properties
-
channel
→ Future<
RpcSubscriptionsChannel> -
The channel (may be a pending future or resolved channel).
final
- dispose → void Function()
-
Disposes this pool entry by aborting the underlying channel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionCount ↔ int
-
The number of active subscribers on this channel.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited